# Scheduling and Allocation Programs

Scheduler and Allocation - create teacher/lab/course schedules

This program comes with ABSOLUTELY NO WARRANTY.

This is free software, and licensed under the GNU General Public License. (see <https://www.gnu.org/licenses/>)


# COPYRIGHT

Copyright (c) 2025, Sandy Bultena

Copyright (c) 2016, Jack Burns, Sandy Bultena, Ian Clement. 
